import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.lang.Class.*;
import java.util.List;
import java.util.ArrayList;



/**
 * A Mover is an actor that also has 'move' and 'turn' ability. Both moving and turning 
 * are relative to its current position. When moving, the Mover will move in the direction 
 * it is currently facing.
 * 
 * Both 'move' and 'turn' methods are available with or without parameters.
 * 
 * The 'Mover' class is a subclass of Actor. It can be used by creating subclasses, or
 * copied into scenarios and edited inline.
 * 
 * The initial direction is to the right. Thus, this class works best with images that
 * face right when not rotated.
 * 
 * This class can also check whether we are close to the edge of the world.
 * 
 * @author Michael Kolling
 * @version 1.0 (July 2007)
 */
public class Mover extends Actor
{
     private static final int acceleration = 2;      // down (gravity)
     private static final double WALKING_SPEED = 5.0;
     private static final int speed = 5;             // running speed (sideways)
     private int fuerzaSalto=20;
     private int vSpeed = 0;                         // current vertical speed
    
    /**
     * Turn 90 degrees to the right (clockwise).
     */
    public void turn()
    {
        turn(90);
    }
    

    /**
     * Turn 'angle' degrees towards the right (clockwise).
     */
    public void turn(int angle)
    {
        setRotation(getRotation() + angle);
    }
    

    /**
     * Move a bit forward in the current direction.
     */
    
    public void mueveDerecha()
    {
        setLocation(getX()+speed, getY());
     }
    
    public void mueveIzquierda()
    {
        setLocation(getX()-speed, getY());
    }
    
    public void mueveIzquierdaEne()
    {
        setLocation(getX()-4, getY());
    }
    
    public void mueveDerechaEne()
    {
        setLocation(getX()+4,getY());
    }
    
    public void mueveIzquierdaPlus()
    {
        setLocation(getX()-10, getY());
    }
    
    public void mueveDerechaPlus()
    {
        setLocation(getX()+20, getY());
    }
    
    public void mueveIzquierdaAvion()
    {
        setLocation(getX()-20,getY());
    }

    public void setVSpeed(int speed)
    {
        vSpeed = speed;
    }
    
    public void caida()
    {
        setLocation ( getX(), getY() + vSpeed);
        vSpeed = vSpeed + acceleration;
    }
    
    
    public boolean enTierra()
    {
        Actor piedra = getOneIntersectingObject(Piedra.class);
        return piedra != null;
    }
    
    
    
    /**
     * Move a specified distance forward in the current direction.
     */
    public void move(double distance)
    {
        double angle = Math.toRadians( getRotation() );
        int x = (int) Math.round(getX() + Math.cos(angle) * distance);
        int y = (int) Math.round(getY() + Math.sin(angle) * distance);
        
        setLocation(x, y);
    }

    
    /**
     * Test if we are close to one of the edges of the world. Return true is we are.
     */
    public boolean atWorldEdge()
    {
        if(getX() < 20 || getX() > getWorld().getWidth() - 20)
            return true;
        if(getY() < 20 || getY() > getWorld().getHeight() - 20)
            return true;
        else
            return false;
    }

    
    protected void salta()
    {
        {setVSpeed(-fuerzaSalto);
         caida();
        }
    }
    
    protected void checaCaida()
    {
        if (enTierra()) {
            setVSpeed(0);
        }
        else {
            caida();
        }
    }
    
    
    public boolean canMove()
    {
        
        World myWorld = getWorld();
        int x = getX()+5;
        int y = getY()+5;
       
        if (x >= myWorld.getWidth() || y >= myWorld.getHeight()) {
            return false;
        }
        else if (x < 0 || y < 0) {
            return false;
        }
        
       return false; 
    }  

    
    
    public void perdiste()
    {
        Greenfoot.stopSimulation();
    }
    
  
    public boolean checaMuerto()
    {
      boolean exito = false;
      
      Actor enemigo = getOneIntersectingObject(Enemigo.class);
      if(enemigo!=null)
      {   
          getWorld().removeObject(enemigo); 
          Greenfoot.playSound("yea.wav");
          exito = true;
      }
      return exito;
    }
    
      
    public boolean atSide()
      {
        if(getX() == 0 || getX()== 793)
            return true;
        if(getY()==50 || getY() == 470)
            return true;
        else
            return false;
      }

    }